<?php $pageTitle='Create a well';
include realpath(__DIR__).'/../../core/_common/header.php'; ?>
<script type="text/javascript">

window.addEventListener('DOMContentLoaded',function(){

	ui.grid().box({
		classes:'r1 c2 h1 w1',
		title:'Plates',
		content:'Manage wells and drops through the plate page.'
	});

});

</script>
<?php include realpath(__DIR__).'/../../core/_common/footer.php';